#include "stdio.h"
#include "json_data.h"

void json_print (JsonValue *v) {
  switch (v->type) {
  case JSON_NULL:
    printf ("null\n");
    break;
  case JSON_TRUE:
    printf ("true\n");
    break;
  case JSON_FALSE:
    printf ("false\n");
    break;
  case JSON_NUMBER:
    printf ("%g", v->value.as_number);
    break;
  case JSON_STRING:
    printf ("\"%s\"\n", v->value.as_string);
    break;
  case JSON_ARRAY:
    {
      Vec *vs = v->value.as_array;
      printf ("[");
      if (vec_length (vs) > 0) {
	json_print (*vec_at (vs, 0));
	for (size_t i=1; i < vec_length (vs); i++) {
	  printf (",");
	  json_print (*vec_at (vs, i));
	}
      }
      printf ("]\n");
    }
    break;
  case JSON_OBJECT:
    { Vec *ms = json_object_members(v->value.as_object);
      printf ("{");
      if (vec_length (ms) > 0) {
	JsonMember *m = *vec_at (ms, 0);
	printf ("\"%s\" : ", m->name);
	json_print (m->value);
	for (size_t i=1; i < vec_length (ms); i++) {
	  m = *vec_at (ms, i);
	  printf ("\"%s\" : ", m->name);
	  json_print (m->value);
	}
      }
      printf ("}");
    }
    break;
  }
}
